//////////////////////////////////////////////////////////////////////////
//
// $Id: QAvatarFactory.h,v 1.5 2004/04/13 19:10:10 scharver Exp $
//
// Author: Chris Scharver
// Email: scharver@evl.uic.edu
// Copyright (c) 2003 Electronic Visualization Laboratory,
//                    University of Illinois at Chicago
//
// Permission is hereby granted, free of charge, to any person
// obtaining a copy of this software and associated documentation
// files (the "Software"), to deal in the Software without
// restriction, including without limitation the rights to use, copy,
// modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT.  IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
// DEALINGS IN THE SOFTWARE.
//
//////////////////////////////////////////////////////////////////////////

#ifndef _QAVATARFACTORY_H
#define _QAVATARFACTORY_H

class QAvatar;

/** @brief Factory class generates new QAvatar instances.
    @author Chris Scharver
    $Revision: 1.5 $
    $Date: 2004/04/13 19:10:10 $

    The Factory Method Pattern provides a convenient way to generate
    instances. It's especially beneficial since it avoids the use of
    templates. Since C++ compilers do not have uniform template
    support, the use of a factory allows easily generating instances
    in a general fashion.

    @sa QAvatar, QAvatarManager
*/
class QAvatarFactory
{
public:

  /// Virtual destructor.
  virtual ~QAvatarFactory() {}

  /** @brief Constructs a new avatar.

      This factory method creates a new QAvatar instance. Subclasses
      will instantiate a new instance and return a pointer to that new
      instance. The QAvatarManager calls this method when it needs to
      create a new avatar, and it is the manager that generates the
      identification number for the new avatar.

      @param avatarID unique identification number for the new avatar
      @return pointer to a new QAvatar instance
  */
  virtual QAvatar* createAvatar(const long& avatarID) = 0;
};

#endif /* _QAVATARFACTORY_H */
