//////////////////////////////////////////////////////////////////////////
//
// $Id: QAvatarListener.h,v 1.5 2004/04/13 19:10:10 scharver Exp $
//
// Author: Chris Scharver
// Email: scharver@evl.uic.edu
// Copyright (c) 2003 Electronic Visualization Laboratory,
//                    University of Illinois at Chicago
//
// Permission is hereby granted, free of charge, to any person
// obtaining a copy of this software and associated documentation
// files (the "Software"), to deal in the Software without
// restriction, including without limitation the rights to use, copy,
// modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT.  IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
// DEALINGS IN THE SOFTWARE.
//
//////////////////////////////////////////////////////////////////////////

#ifndef _QAVATARLISTENER_H
#define _QAVATARLISTENER_H

class QAvatar;

/** @brief Listener class which responds to QAvatarManager notifications.
    @author Chris Scharver
    $Revision: 1.5 $
    $Date: 2004/04/13 19:10:10 $

    @sa QAvatar, QAvatarManager
*/
class QAvatarListener
{
public:
  /// Virtual destructor.
  virtual ~QAvatarListener() {}

  /// Notification called when a new avatar arrives.
  virtual void avatarArrive(QAvatar*) = 0;

  /// Notification called when an avatar has new aux data.
  virtual void avatarAux(QAvatar*) = 0;

  /// Notification called when an avatar leaves.
  virtual void avatarBye(QAvatar*) = 0;

  /// Notification called when an avatar has new hello data.
  virtual void avatarHello(QAvatar*) = 0;

  /// Notification called when an avatar has new tracker data.
  virtual void avatarTracker(QAvatar*) = 0;
};

#endif /* _QAVATARLISTENER_H */
